@@ -10,7 +10,8 @@
     m2dfLowerTruncQuantile = 0,
     m2dfRelativeTolerance = .Machine$double.eps^0.25,
     nDiscretize = 100,
-    hSmooth = 0.05
+    hSmooth = 0.05,
+    IQR.fac = 15
 )
 
 distrExOptions <- function(...) {
